
{% extends "Juice/Plugin/User/Account/_layout.html" %}

{% block login_content %}

    {% call widget.panel( login_title or 'Login') %}

        {% if signup_enabled and oauth_enabled %}
            <div class="text-center">
                {{ macros.oauth_providers() }}
            </div>

            <hr>
        {% endif %}

        {% call forms.post(endpoint_namespace % 'login') %}

            {{ forms.hidden("next", value=login_url_next) }}

            {{ forms.input(label="Email", name="email", type="email", data={"validation": "email"}) }}

            {{ forms.input(label="Password", name="password", type="password",
                data={"validation": "required", "validation-error-msg": "Password is required"}) }}

            {{ forms.button("Login", type="submit", class="btn-primary btn-lg btn-block") }}
        {% endcall %}


        <hr>

        {% if signup_enabled %}
            <a class=" pull-left"  href="{{url_for(endpoint_namespace % 'signup', next=login_url_next)}}">Signup</a>
        {% endif %}

        <a class="pull-right" href="{{url_for(endpoint_namespace % 'lost_password')}}">Lost Password</a>
        <div class="clearfix"></div>

    {% endcall %}

{% endblock %}




