{% import "Juice/macros/html.html" as html with context %}
{% import "Juice/macros/menu.html" as menu with context %}
{% import "Juice/macros/widget.html" as widget with context %}

<!DOCTYPE html>
<html>

    <head>
        {{ html.head("%s | " + __.APPLICATION_NAME) }}
        {{ html.bootswatch_theme('yeti') }}
        {{ html.css("all-css") }}
    </head>

    <body>

        {# HEADER #}
        <header>
            {{ menu.navbar(brand=__.APPLICATION_NAME, exclude_groups=["admin"]) }}
        </header>

        {# BODY #}
        <div class="container">
            <div class="row">
                <div class="col-md-12">
                    {{ widget.flashed_messages() }}
                </div>
            </div>

            {# The content of the site will be included here automatically #}
            {% include __template__ %}
        </div>

        {# FOOTER #}
        <footer>
            <div class="container-fluid">
                <div class="row">
                    <div class="col-md-12">
                        <div class="text-center">
                            <hr>
                            &copy; {{ __.__YEAR__ }} {{ __.APPLICATION_NAME }} {{ __.APPLICATION_VERSION }}
                        </div>
                    </div>
                </div>
            </div>
        </footer>


        {{ html.js("all-js") }}

    </body>
</html>



