img.responsive {
  display: inline-block;
  height: auto;
  max-width: 100%; }

.image-circle {
  border-radius: 50%; }

img.juice-profile-avatar {
  position: relative;
  -webkit-border-radius: 50%;
  -moz-border-radius: 50%;
  border-radius: 50%;
  width: 100px;
  height: 100px; }
  img.juice-profile-avatar-30 {
    position: relative;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    width: 30px;
    height: 30px; }
  img.juice-profile-avatar-40 {
    position: relative;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    width: 40px;
    height: 40px; }
  img.juice-profile-avatar-50 {
    position: relative;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    width: 50px;
    height: 50px; }
  img.juice-profile-avatar-100 {
    position: relative;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    width: 100px;
    height: 100px; }
  img.juice-profile-avatar-150 {
    position: relative;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    width: 150px;
    height: 150px; }
  img.juice-profile-avatar-200 {
    position: relative;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    width: 200px;
    height: 200px; }
  img.juice-profile-avatar-250 {
    position: relative;
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
    width: 250px;
    height: 250px; }

.juice-share-buttons {
  font-size: 20px; }
  .juice-share-buttons a {
    text-decoration: none !important; }

/*# sourceMappingURL=juice.css.map */
