
{% extends "Juice/Plugin/User/Account/_layout.html" %}

{% block login_content %}

    {% call widget.panel('Signup') %}

        {{ widget.alert('Continue by setting up your email and password', 'warning') }}

        {% call forms.post(endpoint_namespace % 'signup') %}

            {{ forms.hidden("next", value=login_url_next) }}

            {{ forms.input(label="Email", name="email", type="email", data={"validation": "email"}) }}

            {{ forms.input(label="Password", name="password", type="password",
                data={"validation": "required",
                      "validation-error-msg": "Password is required"}) }}

            {{ forms.input(label="Confirm Password", name="password2", type="password",
                data={"validation":"required",
                      "validation-confirm":"password",
                      "validation-error-msg": "Password is required"}) }}


            {{ forms.button("Finish Account Creation", type="submit", class="btn-primary btn-lg btn-block") }}
        {% endcall %}

    {% endcall %}

{% endblock %}




