//colors
$color_cape_cod_approx: #404040;
$color_deep_cerulean_approx: #0085a1;
$gray: #808080;
$white: white;
$color_gallery_approx: #eeeeee;

//fonts
$font_0: Open Sans;
$font_1: Helvetica Neue;
$font_2: Helvetica;
$font_3: Arial;
$font_4: sans-serif;
$font_5: Lora;
$font_6: Times New Roman;
$font_7: serif;

//@extend-elements
//original selectors
//.intro-header .site-heading .subheading, .intro-header .page-heading .subheading
%extend_1 {
	font-size: 24px;
	line-height: 1.1;
	display: block;
	font-family: $font_0, $font_1, $font_2, $font_3, $font_4;
	font-weight: 300;
	margin: 10px 0 0;
}

//original selectors
//.pager li > a, .pager li > span
%extend_2 {
	font-family: $font_0, $font_1, $font_2, $font_3, $font_4;
	text-transform: uppercase;
	font-size: 14px;
	font-weight: 800;
	letter-spacing: 1px;
	padding: 15px 25px;
	background-color: $white;
	//Instead of the line below you could use @include border-radius($radius, $vertical-radius)
	border-radius: 0;
}

//original selectors
//.pager li > a:hover, .pager li > a:focus
%extend_3 {
	color: $white;
	background-color: $color_deep_cerulean_approx;
	border: 1px solid $color_deep_cerulean_approx;
}

//original selectors
//.pager .disabled > a, .pager .disabled > a:hover, .pager .disabled > a:focus, .pager .disabled > span
%extend_4 {
	color: $gray;
	background-color: $white;
	cursor: not-allowed;
    border: 0px;
}

.Publisher-Page {
    p {
        line-height: 1.5;
        margin: 30px 0;
        a {
            text-decoration: underline;
        }
    }
    h1 {
        font-family: $font_0, $font_1, $font_2, $font_3, $font_4;
        font-weight: 800;
    }
    h2 {
        font-family: $font_0, $font_1, $font_2, $font_3, $font_4;
        font-weight: 800;
    }
    h3 {
        font-family: $font_0, $font_1, $font_2, $font_3, $font_4;
        font-weight: 800;
    }
    h4 {
        font-family: $font_0, $font_1, $font_2, $font_3, $font_4;
        font-weight: 800;
    }
    h5 {
        font-family: $font_0, $font_1, $font_2, $font_3, $font_4;
        font-weight: 800;
    }
    h6 {
        font-family: $font_0, $font_1, $font_2, $font_3, $font_4;
        font-weight: 800;
    }
    a {
        color: $color_cape_cod_approx;
        &:hover {
            color: $color_deep_cerulean_approx;
        }
        &:focus {
            color: $color_deep_cerulean_approx;
        }
        img {
            &:hover {
                cursor: zoom-in;
            }
            &:focus {
                cursor: zoom-in;
            }
        }
    }
    blockquote {
        color: $gray;
        font-style: italic;
    }

    .post-header{
              padding-bottom: 10px;
              padding-bottom: 40px;
              color: $color_cape_cod_approx;
              h1 {
                  font-size: 65px;
              }
              .subheading {
                  line-height: 1.1;
                  display: block;
                  font-family: $font_0, $font_1, $font_2, $font_3, $font_4;
                  font-size: 24px;
                  margin: 10px 0 30px;
                  font-weight: 600;
              }
              .meta {
                  line-height: 1.1;
                  display: block;
                  font-family: $font_5, $font_6, $font_7;
                  font-style: italic;
                  font-weight: 300;
                  font-size: 20px;
                  a {
                      color: $color_cape_cod_approx;
                  }
              }
          }

    .post-content {
        font-size: 18px;

        img {
            width: 100%;
            height: auto;
        }
    }

    .post-preview > {
        a {
            color: $color_cape_cod_approx;
            &:hover {
                text-decoration: none;
                color: $color_deep_cerulean_approx;
            }
            &:focus {
                text-decoration: none;
                color: $color_deep_cerulean_approx;
            }
            > {
                .post-title {
                    font-size: 30px;
                    margin-top: 30px;
                    margin-bottom: 10px;
                }
                .post-subtitle {
                    margin: 0;
                    font-weight: 300;
                    margin-bottom: 10px;
                }
            }
        }
        .post-meta {
            color: $gray;
            font-size: 18px;
            font-style: italic;
            margin-top: 0;
            > a {
                text-decoration: none;
                color: $color_cape_cod_approx;
                &:hover {
                    color: $color_deep_cerulean_approx;
                    text-decoration: underline;
                }
                &:focus {
                    color: $color_deep_cerulean_approx;
                    text-decoration: underline;
                }
            }
        }
    }

    .section-heading {
        font-size: 36px;
        margin-top: 60px;
        font-weight: 700;
    }
    .caption {
        text-align: center;
        font-size: 14px;
        padding: 10px;
        font-style: italic;
        margin: 0;
        display: block;
        //Instead of the line below you could use @include border-bottom-right-radius($radius)
        border-bottom-right-radius: 5px;
        //Instead of the line below you could use @include border-bottom-left-radius($radius)
        border-bottom-left-radius: 5px;
    }
    .floating-label-form-group {
        font-size: 14px;
        position: relative;
        margin-bottom: 0;
        padding-bottom: 0.5em;
        border-bottom: 1px solid $color_gallery_approx;
    }

    .pager {
        margin: 20px 0 0;
        li > {
            a {
                @extend %extend_2;
                &:hover {
                    @extend %extend_3;
                }
                &:focus {
                    @extend %extend_3;
                }
            }
            span {
                @extend %extend_2;
            }
        }
        .disabled > {
            a {
                @extend %extend_4;
                &:hover {
                    @extend %extend_4;
                }
                &:focus {
                    @extend %extend_4;
                }
            }
            span {
                @extend %extend_4;
            }
        }
    }



    img::selection {
        color: $white;
        background: transparent;
    }
    img::-moz-selection {
        color: $white;
        background: transparent;
    }

}
