

 {% macro title(post) %}
    {{ post.title }}
 {% endmacro %}

{% macro top_media(post) %}
    {% if post.featured_media_top == "embed" and post.featured_embed%}
        {{ base.oembed(post.featured_embed) }}
    {% elif post.featured_media_top == "image" and post.featured_image %}
        {{ base.img_src(post.featured_image) }}
    {% endif %}
{% endmacro %}


{% macro content(post) %}
    {{ post.content | markdown(lazy_images=true) | safe }}
{% endmacro %}

{% macro author_with_link(post) %}
    {% if post.author %}
        <a href="{{ post.author.url }}">{{ post.author.name }}</a>
    {% endif %}
{% endmacro %}


{% macro published_date(post) %}
    {{ post.published_at | date_since }}
{% endmacro %}
