.Publisher-Page .pager li > a, .Publisher-Page .pager li > span {
  font-family: Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif;
  text-transform: uppercase;
  font-size: 14px;
  font-weight: 800;
  letter-spacing: 1px;
  padding: 15px 25px;
  background-color: white;
  border-radius: 0; }

.Publisher-Page .pager li > a:hover, .Publisher-Page .pager li > a:focus {
  color: white;
  background-color: #0085a1;
  border: 1px solid #0085a1; }

.Publisher-Page .pager .disabled > a, .Publisher-Page .pager .disabled > a:hover, .Publisher-Page .pager .disabled > a:focus, .Publisher-Page .pager .disabled > span {
  color: #808080;
  background-color: white;
  cursor: not-allowed;
  border: 0px; }

.Publisher-Page p {
  line-height: 1.5;
  margin: 30px 0; }
  .Publisher-Page p a {
    text-decoration: underline; }
.Publisher-Page h1 {
  font-family: Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif;
  font-weight: 800; }
.Publisher-Page h2 {
  font-family: Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif;
  font-weight: 800; }
.Publisher-Page h3 {
  font-family: Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif;
  font-weight: 800; }
.Publisher-Page h4 {
  font-family: Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif;
  font-weight: 800; }
.Publisher-Page h5 {
  font-family: Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif;
  font-weight: 800; }
.Publisher-Page h6 {
  font-family: Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif;
  font-weight: 800; }
.Publisher-Page a {
  color: #404040; }
  .Publisher-Page a:hover {
    color: #0085a1; }
  .Publisher-Page a:focus {
    color: #0085a1; }
  .Publisher-Page a img:hover {
    cursor: zoom-in; }
  .Publisher-Page a img:focus {
    cursor: zoom-in; }
.Publisher-Page blockquote {
  color: #808080;
  font-style: italic; }
.Publisher-Page .post-header {
  padding-bottom: 10px;
  padding-bottom: 40px;
  color: #404040; }
  .Publisher-Page .post-header h1 {
    font-size: 65px; }
  .Publisher-Page .post-header .subheading {
    line-height: 1.1;
    display: block;
    font-family: Open Sans, Helvetica Neue, Helvetica, Arial, sans-serif;
    font-size: 24px;
    margin: 10px 0 30px;
    font-weight: 600; }
  .Publisher-Page .post-header .meta {
    line-height: 1.1;
    display: block;
    font-family: Lora, Times New Roman, serif;
    font-style: italic;
    font-weight: 300;
    font-size: 20px; }
    .Publisher-Page .post-header .meta a {
      color: #404040; }
.Publisher-Page .post-content {
  font-size: 18px; }
  .Publisher-Page .post-content img {
    width: 100%;
    height: auto; }
.Publisher-Page .post-preview > a {
  color: #404040; }
  .Publisher-Page .post-preview > a:hover {
    text-decoration: none;
    color: #0085a1; }
  .Publisher-Page .post-preview > a:focus {
    text-decoration: none;
    color: #0085a1; }
  .Publisher-Page .post-preview > a > .post-title {
    font-size: 30px;
    margin-top: 30px;
    margin-bottom: 10px; }
  .Publisher-Page .post-preview > a > .post-subtitle {
    margin: 0;
    font-weight: 300;
    margin-bottom: 10px; }
.Publisher-Page .post-preview > .post-meta {
  color: #808080;
  font-size: 18px;
  font-style: italic;
  margin-top: 0; }
  .Publisher-Page .post-preview > .post-meta > a {
    text-decoration: none;
    color: #404040; }
    .Publisher-Page .post-preview > .post-meta > a:hover {
      color: #0085a1;
      text-decoration: underline; }
    .Publisher-Page .post-preview > .post-meta > a:focus {
      color: #0085a1;
      text-decoration: underline; }
.Publisher-Page .section-heading {
  font-size: 36px;
  margin-top: 60px;
  font-weight: 700; }
.Publisher-Page .caption {
  text-align: center;
  font-size: 14px;
  padding: 10px;
  font-style: italic;
  margin: 0;
  display: block;
  border-bottom-right-radius: 5px;
  border-bottom-left-radius: 5px; }
.Publisher-Page .floating-label-form-group {
  font-size: 14px;
  position: relative;
  margin-bottom: 0;
  padding-bottom: 0.5em;
  border-bottom: 1px solid #eeeeee; }
.Publisher-Page .pager {
  margin: 20px 0 0; }
.Publisher-Page img::selection {
  color: white;
  background: transparent; }
.Publisher-Page img::-moz-selection {
  color: white;
  background: transparent; }

/*# sourceMappingURL=page.css.map */
