/**
 *  JQUERY-FORM-VALIDATOR
 *
 *  @website by 
 *  @license MIT
 *  @version 2.2.81
 */
!function(a,b){"use strict";var c='[type="button"], [type="submit"], [type="radio"], [type="checkbox"], [type="reset"], [type="search"]',d=function(a){var b=Math.floor(a.length/2);return[a.substr(0,b),a.substr(b,a.length-b)]},e={upper:function(a){return a.toLocaleUpperCase()},lower:function(a){return a.toLocaleLowerCase()},trim:function(b){return a.trim(b)},trimLeft:function(b){if(b.length>1){var c=d(b);b=a.trim(c[0])+c[1]}return b},trimRight:function(b){if(b.length>1){var c=d(b);b=c[0]+a.trim(c[1])}return b},capitalize:function(b){var c=b.split(" ");return a.each(c,function(a,b){c[a]=b.substr(0,1).toUpperCase()+b.substr(1,b.length)}),c.join(" ")},insert:function(a,b,c){var d=(b.attr("data-sanitize-insert-"+c)||"").replace(/\[SPACE\]/g," ");return"left"==c&&0==a.indexOf(d)||"right"==c&&a.substring(a.length-d.length)==d?a:("left"==c?d:"")+a+("right"==c?d:"")},insertRight:function(a,b){return this.insert(a,b,"right")},insertLeft:function(a,b){return this.insert(a,b,"left")},numberFormat:function(a,c){if(!("numeral"in b))throw new Error('Using sanitation function "numberFormat" requires that you include numeraljs (http://http://numeraljs.com/)');return a=numeral(a).format(c.attr("data-sanitize-number-format"))},escape:function(b){var c={"<":"__%AMP%__lt;",">":"__%AMP%__gt;","&":"__%AMP%__amp;","'":"__%AMP%__#8217;",'"':"__%AMP%__quot;"};return a.each(c,function(a,c){b=b.replace(new RegExp(a,"g"),c)}),b.replace(new RegExp("__%AMP%__","g"),"&")}},f=function(b,d,f){d||(d=a("form")),d.each||(d=a(d));var g=function(){var b=a(this),c=b.val();a.split(b.attr("data-sanitize"),function(a){if(!(a in e))throw new Error('Use of unknown sanitize command "'+a+'"');c=e[a](c,b,f)}),b.val(c).trigger("keyup.validation")};d.each(function(){var b=a(this);f.sanitizeAll&&b.find("input,textarea").not(c).each(function(){a(this).attr("data-sanitize",f.sanitizeAll+" "+(a(this).attr("data-sanitize")||""))}),b.find("[data-sanitize]").unbind("blur",g).bind("blur",g)})};a(b).on("validatorsLoaded formValidationSetup",f),a.formUtils.setupSanitation=f}(jQuery,window);