
{% import "Juice/macros/forms.html" as forms %}

<div id="contact-page">
	<div class="container">

		<div class="row">

			<div class="col-sm-10 col-md-offset-1">

				<h2>Contact Us</h2>

				<hr>

				<div id="contact-edit-form">

                    {% call forms.post(endpoint_namespace % 'ContactPage', class='contact-form') %}

                        <div class="row">
							<div class="col-sm-6">
                                {{ forms.input(label="Name", name="name", data={"validation": "required"}) }}
							</div>
							<div class="col-sm-6">
                                {{ forms.input(label="Email", name="email", data={"validation": "email"}) }}
							</div>
							<div class="col-sm-12">
                                {{ forms.input(label="Subject", name="subject", data={"validation": "required"}) }}
							</div>
							<div class="col-sm-12">
                                {{ forms.textarea(label="Message", name="message", rows=8, data={"validation": "required"}) }}
							</div>
                        </div>

						<div class="form-group pull-right">
							{{ recaptcha }}
						</div>

						<div class="form-group">
                            {{ forms.button("Send Message", type="Submit", class="btn btn-primary") }}
						</div>

                    {% endcall %}

				</div>
			</div>
		</div>
	</div>
</div>


