{% import "Juice/macros/html.html" as html with context %}
{% import "Juice/macros/forms.html" as forms with context %}
{% import "Juice/macros/widget.html" as widget with context %}

<div class="row">
    <div class="col-md-4 col-md-offset-4">
        {% block login_content %}{% endblock %}
    </div>
</div>